==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboBoxUI__24ComboBoxLayoutManager.h <==
// public class javax.swing.plaf.basic.BasicComboBoxUI$ComboBoxLayoutManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 56d785746cb9938e javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$_init$2bc13d637ee2ba7f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *);
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Component$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *);
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Component$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods	javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicComboBoxUI__24ComboBoxLayoutManager.h <==
// public class javax.swing.plaf.basic.BasicComboBoxUI$ComboBoxLayoutManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6a4b623a5f668709 javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$_init$2bc13d637ee2ba7f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vmethods	javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$vtype _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ComboBoxLayoutManager_H_ */
